@@ -250,7 +250,7 @@ vcfR2tidy <- function(x,
   
 #### extract the INFO data. and return if that is all the is requested ####
   # get the base fix data as a data frame
-  base <- as.data.frame(x@fix, stringsAsFactors = FALSE) %>% dplyr::tbl_df()
+  base <- as.data.frame(x@fix, stringsAsFactors = FALSE) %>% tibble::as.tibble()
   base$POS <- as.integer(base$POS)
   base$QUAL <- as.numeric(base$QUAL)
   if(toss_INFO_column == TRUE) {
@@ -262,8 +262,9 @@ vcfR2tidy <- function(x,
   
   fix <- do.call(what = extract_info_tidy, args = info_dots)
   if(info_only == TRUE) {
-    ret <- cbind(base, fix) %>% 
-      dplyr::tbl_df() %>%
+#    ret <- cbind(base, fix) %>% 
+    ret <- dplyr::bind_cols(base, fix) %>% 
+      tibble::as.tibble() %>%
       dplyr::select_(~ -Key)
     
     # only retain meta info for the fields that we are returning
@@ -283,9 +284,10 @@ vcfR2tidy <- function(x,
   
   # if the user is asking for a single data frame we give it to them here:
   if(single_frame == TRUE) {
-    ret <- cbind(base, fix) %>%
+#    ret <- cbind(base, fix) %>%
+    ret <- dplyr::bind_cols(base, fix) %>%
       dplyr::left_join(gt, by = "Key") %>%
-      dplyr::tbl_df() %>%
+      tibble::as.tibble() %>%
       dplyr::select_(~ -Key)  # no point in keeping Key around at this point
     
     info_meta <- info_meta_full %>%
@@ -300,8 +302,9 @@ vcfR2tidy <- function(x,
   # if the user is not asking for a single data frame then we return a list 
   # which has appropriate keys for getting the fix and the gt associated
   # appropriately.
-  retfix <- cbind(base, fix) %>%
-    dplyr::tbl_df() %>%
+#  retfix <- cbind(base, fix) %>%
+  retfix <- dplyr::bind_cols(base, fix) %>%
+    tibble::as.tibble() %>%
     dplyr::mutate_(ChromKey = ~as.integer(factor(CHROM), levels = unique(CHROM))) %>%
     dplyr::select_(~ChromKey, ~dplyr::everything())  # note that we will drop Key from this after we have used it
   
@@ -351,7 +354,7 @@ extract_info_tidy <- function(x, info_fields = NULL, info_types = TRUE, info_sep
   
   vcf <- x
   x <- as.data.frame(x@fix, stringsAsFactors = FALSE) %>% 
-    dplyr::tbl_df()
+    tibble::as.tibble()
   
   # if info_fields is NULL then we try to do all of them
   if(is.null(info_fields)) {
@@ -372,7 +375,7 @@ extract_info_tidy <- function(x, info_fields = NULL, info_types = TRUE, info_sep
   # pick them out in order using info_fields
   ret <- stringr::str_split(string = x$INFO, pattern = info_sep) %>%
     lapply(function(x) {
-      y <- stringr::str_split(x, pattern = "=")
+      y <- stringr::str_split(x, pattern = "=", n = 2)
       vals <- unlist(lapply(y, function(z) z[2]))
       names(vals) <- unlist(lapply(y, function(z) z[1]))
       unname(vals[info_fields])
@@ -381,7 +384,7 @@ extract_info_tidy <- function(x, info_fields = NULL, info_types = TRUE, info_sep
     matrix(ncol = length(info_fields), byrow = TRUE) %>%
     as.data.frame(stringsAsFactors = FALSE) %>%
     setNames(info_fields) %>%
-    dplyr::tbl_df()
+    tibble::as.tibble()
   
   if(!is.null(info_types)) {
     ns <- info_types[!is.na(info_types) & info_types == "n"]
@@ -405,7 +408,7 @@ extract_info_tidy <- function(x, info_fields = NULL, info_types = TRUE, info_sep
     }
     
   }
-  cbind(Key = 1:nrow(ret), ret) %>% dplyr::tbl_df()
+  cbind(Key = 1:nrow(ret), ret) %>% tibble::as.tibble()
 }
 
 #### extract_gt_tidy ####
@@ -565,32 +568,43 @@ guess_types <- function(D) {
 #' 
 #' @export
 vcf_field_names <- function(x, tag = "INFO") {
-  
   if(class(x) != "vcfR") stop("Expecting x to be a vcfR object, not a ", class(x))
-  
+  if( tag != 'INFO' & tag != 'FORMAT') stop("Expecting tag to either be INFO or FORMAT")
+
+  # Subset to tag.
   x <- x@meta
-  y <- dplyr::data_frame(x = x)  # make a data frame of it for easy manipulation
+  left_regx <- paste("^##", tag, "=<", sep = "")  # regex to match and replace 
+  x <- x[grep(left_regx, x)]
+  # Clean up the string ends.
+  x <- sub(left_regx, "", x)
+  x <- sub(">$", "", x)
+
+  # Delimit on quote protected commas.
+  x <- lapply(x, function(x){scan(text=x, what="character", sep=",", quiet = TRUE)})
+
+  # Get unique keys.
+  myKeys <- unique(unlist(lapply(strsplit(unlist(x), split = "="), function(x){x[1]})))
+  # Omit default keys so we can make them first.
+  myKeys <- grep("^ID$|^Number$|^Type$|^Description$", myKeys, invert = TRUE, value = TRUE)
+  myKeys <- c("ID", "Number", "Type", "Description", myKeys)
+
+  myReturn <- data.frame(matrix(ncol=length(myKeys) + 1, nrow=length(x)))
+  colnames(myReturn) <- c("Tag", myKeys)
+  myReturn[,'Tag'] <- tag
+  getValue <- function(x){
+    myValue <- grep(paste("^", myKeys[i], "=", sep=""), x, value = TRUE)
+    if(length(myValue) == 0){
+      is.na(myValue) <- TRUE
+    } else {
+      myValue <- sub(".*=", "", myValue)
+    }
+    myValue
+  }
   
-  left_regx <- paste("^##", tag, "=<ID=", sep = "")  # regex to match and replace 
-  
-  y %>%
-    dplyr::filter_(~stringr::str_detect(x, left_regx)) %>%
-    dplyr::mutate_(x = ~stringr::str_replace(x, left_regx, "")) %>%
-    dplyr::mutate_(x = ~stringr::str_replace(x, ">$", "")) %>%
-    tidyr::separate_("x", 
-                    into=c("i", "n", "t", "d", "s", "v"), 
-                    sep = ",", 
-                    fill = "right",
-                    remove = FALSE) %>%
-    dplyr::mutate_(Tag = ~tag,
-                  ID = ~i,
-                  Number = ~stringr::str_replace(n, "^Number=", ""),
-                  Type = ~stringr::str_replace(t, "^Type=", ""),
-                  Description = ~stringr::str_replace(d, "^Description=", "") %>% 
-                    stringr::str_replace_all("\"", ""),
-                  Source = ~stringr::str_replace(s, "^Source=", ""),
-                  Version = ~stringr::str_replace(v, "^Version=", "")) %>%
-    dplyr::select_(~Tag, ~ID, ~Number, ~Type, ~Description, ~Source, ~Version)
+  for(i in 1:length(myKeys)){
+    myReturn[,i+1] <- unlist(lapply(x, function(x){ getValue(x) }))
+  }
+  tibble::as_tibble(myReturn)
 }
 
 
