@@ -8,6 +8,45 @@ context("vcfRtidy functions")
 data("vcfR_example")
 #data("vcfR_test")
 
+
+##### ##### ##### ##### #####
+# vcf_field_names
+
+
+test_that("vcf_field_names works",{
+  data("vcfR_example")
+  Z <- vcf_field_names(vcf, tag = "INFO")
+  
+  expect_is(Z, "tbl_df")
+  expect_is(Z, "tbl")
+  expect_is(Z, "data.frame")
+  
+  Z <- vcf_field_names(vcf, tag = "FORMAT")
+
+  expect_is(Z, "tbl_df")
+  expect_is(Z, "tbl")
+  expect_is(Z, "data.frame")
+})
+
+
+test_that("vcf_field_names works, comma in quotes not parsed",{
+   data("vcfR_test")
+   myMeta <- vcfR_test@meta
+   vcfR_test@meta <- c(myMeta[1:12], '##INFO=<ID=AF,Number=A,Type=Float,Description="Estimated allele frequency in the range (0,1]">', myMeta[13:18])
+
+   Z <- vcf_field_names(vcfR_test, tag = "INFO")
+   expect_is(Z, "tbl_df")
+   expect_is(Z, "tbl")
+   expect_is(Z, "data.frame")
+  
+   vcfR_test@meta[13] <- '##INFO=<ID=TYPE,Number=A,Type=String,Description="The type of allele, either snp, mnp, ins, del, or complex.">'
+   Z <- vcf_field_names(vcfR_test)
+   
+   expect_is(Z, "tbl_df")
+   expect_is(Z, "tbl")
+   expect_is(Z, "data.frame")
+})
+
 ##### ##### ##### ##### #####
 # extract_gt_tidy
 
@@ -49,6 +88,14 @@ test_that("vcfR2tidy works",{
   
 })
 
+test_that("vcfR2tidy works, ID=REF",{
+   data("vcfR_test")
+   myMeta <- vcfR_test@meta
+   vcfR_test@meta <- c(myMeta[1:12], '##INFO=<ID=REF,Number=0,Type=Flag,Description="Has reference A coding region variation where one allele in the set is identical to the reference sequence. FxnCode = 8">', myMeta[13:18])  
+   Z <- vcfR2tidy(vcf, info_only = FALSE, verbose = FALSE)
+#   Z$meta
+
+})
 
 ##### ##### ##### ##### #####
 # extract_info_tidy
@@ -73,22 +120,5 @@ test_that("extract_info_tidy works with Flags",{
 })
 
 
-##### ##### ##### ##### #####
-# vcf_field_names
-
-
-test_that("vcf_field_names works",{
-  Z <- vcf_field_names(vcf, tag = "INFO")
-  
-  expect_is(Z, "tbl_df")
-  expect_is(Z, "tbl")
-  expect_is(Z, "data.frame")
-  
-  Z <- vcf_field_names(vcf, tag = "FORMAT")
-
-  expect_is(Z, "tbl_df")
-  expect_is(Z, "tbl")
-  expect_is(Z, "data.frame")
-})
 
 
